@@ -37,7 +37,6 @@ class TagSchema(AttrsSchema):
 class Badge:
     badge_name: str = attr.ib()
     category: str = attr.ib()
-    badge_type: str = attr.ib()
 
 
 class BadgeSchema(AttrsSchema):
@@ -62,6 +61,9 @@ class WatermarkSchema(AttrsSchema):
 
 @attr.s(auto_attribs=True, kw_only=True)
 class Statistics:
+    """
+    DEPRECATED. Use Stat
+    """
     stat_type: str
     stat_val: Optional[str] = None
     start_epoch: Optional[int] = None
@@ -69,18 +71,36 @@ class Statistics:
 
 
 class StatisticsSchema(AttrsSchema):
+    """
+    DEPRECATED. Use StatSchema
+    """
     class Meta:
         target = Statistics
         register_as_scheme = True
 
 
+@attr.s(auto_attribs=True, kw_only=True)
+class Stat:
+    stat_type: str
+    stat_val: Optional[str] = None
+    start_epoch: Optional[int] = None
+    end_epoch: Optional[int] = None
+
+
+class StatSchema(AttrsSchema):
+    class Meta:
+        target = Stat
+        register_as_scheme = True
+
+
 @attr.s(auto_attribs=True, kw_only=True)
 class Column:
     name: str
+    key: Optional[str] = None
     description: Optional[str] = None
     col_type: str
     sort_order: int
-    stats: List[Statistics] = []
+    stats: List[Stat] = []
 
 
 class ColumnSchema(AttrsSchema):
@@ -115,6 +135,7 @@ class SourceSchema(AttrsSchema):
         target = Source
         register_as_scheme = True
 
+
 @attr.s(auto_attribs=True, kw_only=True)
 class ResourceReport:
     name: str
@@ -151,6 +172,7 @@ class Table:
     cluster: str
     schema: str
     name: str
+    key: Optional[str] = None
     tags: List[Tag] = []
     badges: List[Badge] = []
     table_readers: List[Reader] = []
